AdWithView class abstract

Inheritance
Implementers

Constructors

AdWithView({required String licenseKey, required AdWithViewListener listener})

Properties

hashCode → int
The hash code for this object.
no setterinherited
licenseKey → String
finalinherited
listener → AdWithViewListener
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
inherited
load() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited