VponAdRequest class

Constructors

VponAdRequest()

Properties

contentData ↔ Map<String, dynamic>
getter/setter pair
contentUrl ↔ String?
getter/setter pair
extraData ↔ Map<String, dynamic>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keywords ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addContentData({required String key, required String value}) → void
新增 content data
addKeyword(String keyword) → void
設定關鍵字
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited