VponRequestConfiguration class

Constructors

VponRequestConfiguration({VponMaxAdContentRating? maxAdContentRating, VponTagForChildDirectedTreatment? tagForChildDirectedTreatment, VponTagForUnderAgeOfConsent? tagForUnderAgeOfConsent, List<String>? testDeviceIds})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxAdContentRating → VponMaxAdContentRating?
最高可投放的年齡(分類)限制
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagForChildDirectedTreatment → VponTagForChildDirectedTreatment?
是否專為兒童投放
final
tagForUnderAgeOfConsent → VponTagForUnderAgeOfConsent?
是否專為特定年齡投放
final
testDeviceIds → List<String>?
測試用的裝置 IDFA,以取得 Vpon 測試廣告
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited