InterstitialAd class

Inheritance

Properties

adLoadCallback → InterstitialAdLoadCallback
final
fullScreenContentCallback ↔ FullScreenContentCallback<InterstitialAd>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
licenseKey → String
finalinherited
request → VponAdRequest
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

load({required String licenseKey, required VponAdRequest request, required InterstitialAdLoadCallback adLoadCallback}) → Future<void>