NativeAd class

Inheritance

Constructors

NativeAd({required String licenseKey, required String? factoryId, required NativeAdListener listener, required VponAdRequest? request})

Properties

factoryId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
licenseKey → String
finalinherited
listener → NativeAdListener
final
request → VponAdRequest?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
inherited
load() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited